==> google_applovin_unity_ads-2.3.15.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinInterstitialAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.ads.MaxInterstitialAd;
import com.applovin.sdk.AppLovinSdk;
import com.google.android.gms.ads.AdError;
import com.google.android.gms.ads.LoadAdError;

import java.lang.ref.WeakReference;

class FlutterAppLovinInterstitialAd extends FlutterAd.FlutterOverlayAd {
    private static final String TAG = "FlutterAppLovinIntraAd";
    @NonNull
    final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final AppLovinSdk appLovinSdk;
    @Nullable
    private MaxInterstitialAd ad;
    @Nullable
    private GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory geoSdkFactory;
    @NonNull
    private final FlutterAdLoader flutterAdLoader;


    public FlutterAppLovinInterstitialAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull AppLovinSdk appLovinSdk,
            @NonNull FlutterAdLoader flutterAdLoader,
            GoogleApplovinUnityAdsPlugin.GeoedgeSdkFactory sdkFactory) {
        super(adId);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.appLovinSdk = appLovinSdk;
        this.flutterAdLoader = flutterAdLoader;
        this.geoSdkFactory = sdkFactory;
    }

    @Override
    void load() {
        if (manager != null && adUnitId != null && appLovinSdk != null) {
            ad = new MaxInterstitialAd(adUnitId, appLovinSdk, manager.getActivity());
            MaxAdListener callback = new DelegatingApplovinInterstitialAdLoadCallback(this);
            if (geoSdkFactory != null) {
                geoSdkFactory.setGeoIntraListener(ad, callback);
            } else {
                ad.setListener(callback);
            }
            ad.loadAd();
        }
    }

    void onAdLoaded(MaxAd intraad) {
        manager.onAdLoaded(adId, null);
    }

    void onAdFailedToLoad(LoadAdError loadAdError) {
        manager.onAdFailedToLoad(adId, new FlutterLoadAdError(loadAdError));
    }

    @Override
    void dispose() {
        ad = null;
    }

    @Override
    public void show() {
        if (ad == null) {
            Log.e(TAG, "Error showing interstitial - the interstitial ad wasn't loaded yet.");
            return;
        }

        if (manager.getActivity() == null) {
            Log.e(TAG, "Tried to show interstitial before activity was bound to the plugin.");
            return;
        }

        if (geoSdkFactory != null) {
            if (geoSdkFactory.isGeoAdShow(ad)) {
                ad.showAd();
            } else {
                onAdFailedToLoad(new LoadAdError(8520, "ad is blocked", "", null, null));
            }
        } else {
            ad.showAd();
        }
    }

    @Override
    public void setImmersiveMode(boolean immersiveModeEnabled) {
    }

    /**
     * An InterstitialAdLoadCallback that just forwards events to a delegate.
     */
    private static final class DelegatingApplovinInterstitialAdLoadCallback implements MaxAdListener {

        private final WeakReference<FlutterAppLovinInterstitialAd> delegate;

        DelegatingApplovinInterstitialAdLoadCallback(FlutterAppLovinInterstitialAd delegate) {
            this.delegate = new WeakReference<>(delegate);
        }

        @Override
        public void onAdLoaded(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().onAdLoaded(ad);
            }
        }

        @Override
        public void onAdDisplayed(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdShowedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdHidden(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdDismissedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdClicked(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdClicked(delegate.get().adId);
            }
        }

        @Override
        public void onAdLoadFailed(String adUnitId, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().onAdFailedToLoad(new LoadAdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode()), null, null));
            }
        }

        @Override
        public void onAdDisplayFailed(MaxAd ad, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().manager.onFailedToShowFullScreenContent(delegate.get().adId, new AdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode())));
            }
        }
    }
}

==> google_applovin_unity_ads-2.3.18.tar.gz: android/src/main/java/com/btcpiyush/ads/google_applovin_unity_ads/FlutterAppLovinInterstitialAd.java <==
// Copyright 2022 Bitcoding
// See the License for the specific language governing permissions and
// limitations under the License.

package com.btcpiyush.ads.google_applovin_unity_ads;

import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.appharbr.sdk.engine.AdBlockReason;
import com.appharbr.sdk.engine.AdSdk;
import com.appharbr.sdk.engine.AppHarbr;
import com.appharbr.sdk.engine.adformat.AdFormat;
import com.appharbr.sdk.engine.listeners.AHListener;
import com.applovin.mediation.MaxAd;
import com.applovin.mediation.MaxAdListener;
import com.applovin.mediation.MaxError;
import com.applovin.mediation.ads.MaxInterstitialAd;
import com.applovin.sdk.AppLovinSdk;
import com.google.android.gms.ads.AdError;
import com.google.android.gms.ads.LoadAdError;

import java.lang.ref.WeakReference;

class FlutterAppLovinInterstitialAd extends FlutterAd.FlutterOverlayAd {
    private static final String TAG = "FlutterAppLovinIntraAd";
    @NonNull
    final AdInstanceManager manager;
    @NonNull
    private final String adUnitId;
    @NonNull
    private final AppLovinSdk appLovinSdk;
    @Nullable
    private MaxInterstitialAd ad;
    @NonNull
    private final FlutterAdLoader flutterAdLoader;


    public FlutterAppLovinInterstitialAd(
            int adId,
            @NonNull AdInstanceManager manager,
            @NonNull String adUnitId,
            @NonNull AppLovinSdk appLovinSdk,
            @NonNull FlutterAdLoader flutterAdLoader) {
        super(adId);
        this.manager = manager;
        this.adUnitId = adUnitId;
        this.appLovinSdk = appLovinSdk;
        this.flutterAdLoader = flutterAdLoader;
    }

    @Override
    void load() {
        if (manager != null && adUnitId != null && appLovinSdk != null) {
            ad = new MaxInterstitialAd(adUnitId, appLovinSdk, manager.getActivity());
            MaxAdListener callback = new DelegatingApplovinInterstitialAdLoadCallback(this);


//            if (geoSdkFactory != null) {
                callback = AppHarbr.addInterstitial(
                        AdSdk.MAX,
                        ad,
                        callback,
                        null,
                        (o, s, adFormat, adBlockReasons) -> {}
                );
//            }
            ad.setListener(callback);
            ad.loadAd();
        }
    }

    void onAdLoaded(MaxAd intraad) {
        manager.onAdLoaded(adId, null);
    }

    void onAdFailedToLoad(LoadAdError loadAdError) {
        manager.onAdFailedToLoad(adId, new FlutterLoadAdError(loadAdError));
    }

    @Override
    void dispose() {
        ad = null;
    }

    @Override
    public void show() {
        if (ad == null) {
            Log.e(TAG, "Error showing interstitial - the interstitial ad wasn't loaded yet.");
            return;
        }

        if (manager.getActivity() == null) {
            Log.e(TAG, "Tried to show interstitial before activity was bound to the plugin.");
            return;
        }

        /*if (geoSdkFactory != null) {
            if (geoSdkFactory.isGeoAdShow(ad)) {
                ad.showAd();
            } else {
                onAdFailedToLoad(new LoadAdError(8520, "ad is blocked", "", null, null));
            }
        } else {*/
            ad.showAd();
        /*}*/
    }

    @Override
    public void setImmersiveMode(boolean immersiveModeEnabled) {
    }

    /**
     * An InterstitialAdLoadCallback that just forwards events to a delegate.
     */
    private static final class DelegatingApplovinInterstitialAdLoadCallback implements MaxAdListener {

        private final WeakReference<FlutterAppLovinInterstitialAd> delegate;

        DelegatingApplovinInterstitialAdLoadCallback(FlutterAppLovinInterstitialAd delegate) {
            this.delegate = new WeakReference<>(delegate);
        }

        @Override
        public void onAdLoaded(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().onAdLoaded(ad);
            }
        }

        @Override
        public void onAdDisplayed(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdShowedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdHidden(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdDismissedFullScreenContent(delegate.get().adId);
            }
        }

        @Override
        public void onAdClicked(MaxAd ad) {
            if (delegate.get() != null) {
                delegate.get().manager.onAdClicked(delegate.get().adId);
            }
        }

        @Override
        public void onAdLoadFailed(String adUnitId, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().onAdFailedToLoad(new LoadAdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode()), null, null));
            }
        }

        @Override
        public void onAdDisplayFailed(MaxAd ad, MaxError error) {
            if (delegate.get() != null) {
                delegate.get().manager.onFailedToShowFullScreenContent(delegate.get().adId, new AdError(error.getCode(), error.getMessage(), String.valueOf(error.getMediatedNetworkErrorCode())));
            }
        }
    }
}
